# Table of Contents

- [bulk-updating-data-in-inventory-table-view](<./bulk-updating-data-in-inventory-table-view.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Bulk Updating Data in Inventory Table View](<./Bulk-Updating-Data-in-Inventory-Table-View.md>)
  - [Introduction](<./Bulk-Updating-Data-in-Inventory-Table-View/Introduction.md>)
  - [Table View](<./Bulk-Updating-Data-in-Inventory-Table-View/Table-View.md>)
  - [Inline Editing](<./Bulk-Updating-Data-in-Inventory-Table-View/Inline-Editing.md>)
  - [Editable and Non-Editable Fields](<./Bulk-Updating-Data-in-Inventory-Table-View/Editable-and-Non-Editable-Fields.md>)
  - [Keyboard Accessibility](<./Bulk-Updating-Data-in-Inventory-Table-View/Keyboard-Accessibility.md>)
  - [Bulk Updating Data Through an Excel File](<./Bulk-Updating-Data-in-Inventory-Table-View/Bulk-Updating-Data-Through-an-Excel-File.md>)
